from setuptools import setup

setup(name='udacityMLEdistributions',
      version='0.57',
      description='Gaussian distributions',
      packages=['udacityMLEdistributions'],
      zip_safe=False)
